==> mythbuntu-live-autostart_0.43.orig.tar.gz: mythbuntu-live-autostart-0.43/setup.py <==
#!/usr/bin/python
# Mythbuntu-Live-Autostart install script
# Copyright (C) 2007, Mario Limonciello <superm1@mythbuntu.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup

import subprocess, glob, os.path

setup(
    name="mythbuntu-live-autostart",
    author="Mario Limonciello",
    author_email="superm1@mythbuntu.org",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="manages the live startup session of Mythbuntu",
    packages=[],
    data_files=[("share/mythbuntu/ui",   glob.glob("gui/mythbuntu_live_autostart.ui")),
                ("share/mythbuntu",      glob.glob("artwork/*jpg")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
                ("share/ubiquity/gtk",   glob.glob("ubiquity/gtk/*")),
                ("share/ubiquity",       glob.glob("ubiquity/scripts/*")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
		("share/pixmaps",        glob.glob("ubiquity/ubiquity-mythbuntu.png")),
                ("share/initramfs-tools/scripts/casper-bottom", glob.glob("casper/*"))],
    scripts=["mythbuntu-startup"],
)

==> mythbuntu-live-autostart_0.59.tar.gz: mythbuntu-live-autostart-0.59/setup.py <==
#!/usr/bin/python
# Mythbuntu-Live-Autostart install script
# Copyright (C) 2007, Mario Limonciello <superm1@mythbuntu.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup

import subprocess, glob, os.path

setup(
    name="mythbuntu-live-autostart",
    author="Mario Limonciello",
    author_email="superm1@mythbuntu.org",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="manages the live startup session of Mythbuntu",
    packages=[],
    data_files=[("share/mythbuntu/ui",   glob.glob("gui/mythbuntu_live_autostart.ui")),
                ("share/mythbuntu",      glob.glob("artwork/*")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
                ("share/ubiquity/gtk",   glob.glob("ubiquity/gtk/*")),
                ("share/ubiquity",       glob.glob("ubiquity/scripts/*")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
                ("lib/ubiquity/plugins", glob.glob("ubiquity/plugins/*")),
		("share/pixmaps",        glob.glob("ubiquity/ubiquity-mythbuntu.png")),
                ("share/initramfs-tools/scripts/casper-bottom", glob.glob("casper/*"))],
    scripts=["mythbuntu-startup"],
)
